@@ -1,14 +1,19 @@
 import os
-import sys
+#import sys
 import re
+import logging
+import subprocess
 from pathlib import Path
-from timeit import default_timer as timer
-from datetime import datetime, timedelta
+#from timeit import default_timer as timer
+#from datetime import datetime, timedelta
 
-from mkdocs import utils as mkdocs_utils
+#from mkdocs import utils as mkdocs_utils
 from mkdocs.config import config_options, Config
 from mkdocs.plugins import BasePlugin
 
+log = logging.getLogger(__name__)
+CONVERT_TOOL = os.getenv('CONVERT_TOOL', 'D:/Ceiba/pocs/markdown/bpmn-to-image-test/convert.bat')
+
 class SemosPlugin(BasePlugin):
 
     config_scheme = (
@@ -20,7 +25,12 @@ class SemosPlugin(BasePlugin):
         self.total_time = 0
 
     def on_page_content(self, html, page, config, files):
-        #print(config, files)
+        # print(config, files)
+        # print(page)
+
+        build_dir = config['site_dir']
+        page_path = page.url.replace('/', '\\\\')
+        
         img_regex = '<img(.*?)\/>'
         src_regex = 'src="(.*?)"'
 
@@ -31,32 +41,42 @@ class SemosPlugin(BasePlugin):
             src_match = src.search(item.group())
 
             if src_match:
-                print(item.start(), item.group())
-                #print(src_match.group(1))
+                log.info(item.group())
                 
                 # <img alt="Diagrama solucion!" src="imgs/aws.drawio.svg" title="Diagrama Solución" />
                 # <object data="imgs/componentes.drawio.svg" type="image/svg+xml" id="svg" width="100%" height="100%"></object>
-                html = html.replace(item.group(), f"<object data=\"{src_match.group(1)}\" type=\"image/svg+xml\" id=\"svg\" width=\"100%\" height=\"100%\"></object>")
+                image_file = src_match.group(1)
+
+                if image_file.endswith('.bpmn'):
+                    image_file = image_file + '.svg'
+
+                html = html.replace(item.group(), f"<object data=\"{image_file}\" type=\"image/svg+xml\" id=\"svg\" width=\"100%\" height=\"100%\"></object>")
 
         return html
 
     def on_post_build(self, config):
         build_dir = config['site_dir']
 
-        print('temp dir: ', build_dir)
+        log.info('temp dir: ' + build_dir)
 
         for svg in Path(build_dir).rglob('*.svg'):
             if svg.suffix == '.svg':
-                print(svg)
+                log.info(svg)
+        
+                content = svg.read_text()
+                svg.write_text(content.replace('<a xlink', '<a target="_parent" xlink'))
 
-            content = svg.read_text()
-            svg.write_text(content.replace('<a xlink', '<a target="_parent" xlink'))
+        for bpmn in Path(build_dir).rglob('*.bpmn'):
+            #if bpmn.suffix == '.bpmn':
+            print(bpmn)
+
+            p = subprocess.call([CONVERT_TOOL, bpmn, f"{bpmn}.svg"])
 
         return
 
 #    def on_serve(self, server):
 #        return server
-
+#
 #    def on_pre_build(self, config):
 #        return
 #
